==> react-collapsible-basic-2.11.0.tgz: package/lib/index.js <==
import PropTypes from 'prop-types';
import React, { useState, useEffect } from 'react';
import cx from 'classnames';
import Chevronbottom from '@s-ui/react-icons/lib/Chevronbottom';
var ANIMATION_SPEED_CLASSNAMES = {
  normal: 'sui-CollapsibleBasic-transitionNormal',
  fast: 'sui-CollapsibleBasic-transitionFast'
};

var CollapsibleBasic = function CollapsibleBasic(_ref) {
  var animationSpeed = _ref.animationSpeed,
      children = _ref.children,
      collapsed = _ref.collapsed,
      onClick = _ref.handleClick,
      hideTriggerIcon = _ref.hideTriggerIcon,
      ArrowIcon = _ref.icon,
      isClickable = _ref.isClickable,
      label = _ref.label;

  var _useState = useState(collapsed),
      isCollapsed = _useState[0],
      setIsCollapsed = _useState[1];

  useEffect(function () {
    setIsCollapsed(collapsed);
  }, [collapsed]);

  var handleClick = function handleClick() {
    var nextIsCollapsed = !isCollapsed;
    setIsCollapsed(nextIsCollapsed);
    onClick(nextIsCollapsed);
  };

  var cssClassNames = cx('sui-CollapsibleBasic', {
    'is-collapsed': isCollapsed,
    'is-expanded': !isCollapsed
  });
  var contentCssClassNames = cx('sui-CollapsibleBasic-collapsibleContent', ANIMATION_SPEED_CLASSNAMES[animationSpeed]);
  return React.createElement("div", {
    className: cssClassNames
  }, React.createElement("div", {
    className: "sui-CollapsibleBasic-trigger",
    onClick: isClickable ? handleClick : undefined
  }, React.createElement("div", {
    className: "sui-CollapsibleBasic-trigger-label"
  }, label), !hideTriggerIcon && React.createElement("div", {
    className: "sui-CollapsibleBasic-trigger-iconBox"
  }, React.createElement(ArrowIcon, {
    svgClass: "sui-CollapsibleBasic-trigger-iconBox-icon",
    className: "sui-CollapsibleBasic-trigger-iconBox-icon"
  }))), React.createElement("div", {
    className: contentCssClassNames
  }, children));
};

CollapsibleBasic.displayName = 'CollapsibleBasic';
CollapsibleBasic.defaultProps = {
  icon: Chevronbottom,
  collapsed: true,
  hideTriggerIcon: false,
  animationSpeed: 'normal',
  isClickable: true,
  handleClick: function handleClick() {}
};
export default CollapsibleBasic;

==> react-collapsible-basic-2.12.0.tgz: package/lib/index.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { useState, useEffect } from 'react';
import cx from 'classnames';
import Chevronbottom from '@s-ui/react-icons/lib/Chevronbottom';
var ANIMATION_SPEED_CLASSNAMES = {
  normal: 'sui-CollapsibleBasic-transitionNormal',
  fast: 'sui-CollapsibleBasic-transitionFast'
};

var CollapsibleBasic = function CollapsibleBasic(_ref) {
  var animationSpeed = _ref.animationSpeed,
      children = _ref.children,
      collapsed = _ref.collapsed,
      onClick = _ref.handleClick,
      hideTriggerIcon = _ref.hideTriggerIcon,
      ArrowIcon = _ref.icon,
      isClickable = _ref.isClickable,
      label = _ref.label;

  var _useState = useState(collapsed),
      isCollapsed = _useState[0],
      setIsCollapsed = _useState[1];

  useEffect(function () {
    setIsCollapsed(collapsed);
  }, [collapsed]);

  var handleClick = function handleClick() {
    var nextIsCollapsed = !isCollapsed;
    setIsCollapsed(nextIsCollapsed);
    onClick(nextIsCollapsed);
  };

  var cssClassNames = cx('sui-CollapsibleBasic', {
    'is-collapsed': isCollapsed,
    'is-expanded': !isCollapsed
  });
  var contentCssClassNames = cx('sui-CollapsibleBasic-collapsibleContent', ANIMATION_SPEED_CLASSNAMES[animationSpeed]);
  return /*#__PURE__*/_jsxs("div", {
    className: cssClassNames,
    children: [/*#__PURE__*/_jsxs("div", {
      className: "sui-CollapsibleBasic-trigger",
      onClick: isClickable ? handleClick : undefined,
      children: [/*#__PURE__*/_jsx("div", {
        className: "sui-CollapsibleBasic-trigger-label",
        children: label
      }), !hideTriggerIcon && /*#__PURE__*/_jsx("div", {
        className: "sui-CollapsibleBasic-trigger-iconBox",
        children: /*#__PURE__*/_jsx(ArrowIcon, {
          svgClass: "sui-CollapsibleBasic-trigger-iconBox-icon",
          className: "sui-CollapsibleBasic-trigger-iconBox-icon"
        })
      })]
    }), /*#__PURE__*/_jsx("div", {
      className: contentCssClassNames,
      children: children
    })]
  });
};

CollapsibleBasic.displayName = 'CollapsibleBasic';
CollapsibleBasic.defaultProps = {
  icon: Chevronbottom,
  collapsed: true,
  hideTriggerIcon: false,
  animationSpeed: 'normal',
  isClickable: true,
  handleClick: function handleClick() {}
};
export default CollapsibleBasic;
